prover

package
v0.0.0-...-58399a2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 29, 2026 License: Apache-2.0 Imports: 23 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CheckVanishingRelation

func CheckVanishingRelation(tr trace.Trace, md board.CompiledModule) error

func MergeTrace

func MergeTrace(t1 trace.Trace, t2 ...trace.Trace) trace.Trace

func Prove

func Prove(t trace.Trace, provingKey setup.ProvingKey, publicInputs public.Inputs, program board.Program, opts ...Option) (proof.Proof, error)

func TraceFibonacci

func TraceFibonacci(n int, a, b koalabear.Element) trace.Trace

TraceFibonacci traces a Fibonacci sequence, encoded with 3 columns A, B, C subject to the following constraints: C = A + B A_shifted = B, except at the last entry B_shifted = C, except at the last entry with A[0]=a, B[0]=b

func TraceRange

func TraceRange(n int) trace.Trace

Types

type Config

type Config struct {
	SkipFRI             bool
	HashBackend         fri.HashBackend
	NewTranscriptHasher fiatshamir.NewTranscriptHasher
	PhaseCallback       func(name string, d time.Duration)
	NumFriQueries       int
	FriOptions          []fri.Option
	Fs                  *fiatshamir.Transcript
}

type Option

type Option func(c *Config) error

func SkipFRI

func SkipFRI() Option

func WithFriOption

func WithFriOption(opt fri.Option) Option

WithFriOption adds options for FRI

func WithHashBackend

func WithHashBackend(backend fri.HashBackend) Option

func WithNewTranscriptHasher

func WithNewTranscriptHasher(h fiatshamir.NewTranscriptHasher) Option

func WithNumFriQueries

func WithNumFriQueries(numQueries int) Option

WithNumFriQueries sets FRI NumQueries to numQueries

func WithPhaseCallback

func WithPhaseCallback(cb func(name string, d time.Duration)) Option

WithPhaseCallback installs a callback that fires after each major prover phase with the phase name and wall-clock duration. Phases reported (in order): "execute-steps", "compute-air-quotients", "evaluations-at-zeta", "deep-quotient+fri-commit", "fri-query-open".

func WithTranscript

func WithTranscript(fs *fiatshamir.Transcript) Option

WithTranscript provides a running transcript to the prover

Jump to